#
# spec file for package python-caldav
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global modname caldav
Name:           python-%{modname}
Version:        0.6.2
Release:        bp153.1.16
Summary:        CalDAV (RFC4791) client library for Python
License:        GPL-3.0-or-later AND Apache-2.0
Group:          Development/Languages/Python
URL:            https://pypi.python.org/pypi/%{modname}
Source:         https://files.pythonhosted.org/packages/source/c/caldav/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module vobject}
BuildRequires:  python-rpm-macros
Requires:       python-lxml
Requires:       python-nose
Requires:       python-requests
Requires:       python-six
Requires:       python-vobject
BuildArch:      noarch
%ifpython2
Requires:       python-pytz
Requires:       python-tzlocal
%endif
%python_subpackages

%description
This project is a CalDAV (RFC4791) client library for Python.

It can read all the tags, but only write a few things (create calendars,
events, modify events and properties).

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%check
# almost all tests are online, would require
# caldav server to run

%install
%python_install

%files %{python_files}
%license COPYING.APACHE COPYING.GPL
%{python_sitelib}/%{modname}-%{version}-py*.egg-info
%{python_sitelib}/%{modname}/

%changelog
* Fri Jan 24 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.6.2
  * caldav/lib/error.py - ProppatchError was not defined, ref https://github.com/python-caldav/caldav/issues/54.
    Also added a common base class DAVError, and made sure the error
    referenced in #54 will never reappear, even if new methods are
    added to DAVClient.
  * caldav/elements/cdav.py - fixing a retention problem - the
    timezone fixes done recently was not compatible with python 2.7 nor 3.5.
  * setup.py - reintroducing dependencies pytz and tzlocal - but only for old python versions
  * README.md - proper documentation of the dual licensing, ref
    https://github.com/python-caldav/caldav/issues/60
  * caldav/objects.py - fixes (or workarounds?) that solves real-world
    issues with iCloud and MS Exchange.  Ref https://github.com/python-caldav/caldav/pull/56
* Thu Apr 25 2019 Adrian Schröter <adrian@suse.de>
- version update to 0.6.1
  * bugfix: accept text/calendar (required for fetching calendar items from the xandikos server, ref https://github.com/python-caldav/caldav/issues/40
* Fri Mar 22 2019 pgajdos@suse.com
- version update to 0.6.0
  * caldav/elements/cdav.py - proper timezone support
  * caldav/elements/dav.py - add GetEtag
  * caldav/elements/cdav.py - allow Expand tag to be used with open-ended
    start
  * caldav/objects.py - enhancement: add the ability to add events to
    calendar using directly a vobject object, and not necessarily an ical
    string.
  * caldav/objects.py - bugfix: uid handling while fetching
    elements
  etc. see https://github.com/python-caldav/caldav/blob/master/ChangeLog
- almost all tests are online, do not run
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Jul 10 2017 jengelh@inai.de
- Drop history lesson and future goal wording from description.
* Tue Jun 13 2017 okurz@suse.com
- Update to 0.5.0
- Convert spec file to singlespec
* Fri Jun  3 2016 toddrme2178@gmail.com
- Update to 0.4.0
  * No upstream changelog
- Clean up spec file
* Wed Oct 23 2013 axel.braun@gmx.de
- Initial package ( version 0.1.12 )
